% PLEASE READ THE README FILE BEFORE RUNNING THIS DEMO

% Add the paths of required libraries
startup;

% Set up the parameters of the algorithm (details are in README)
config.num_folds = 5;
config.num_thresholds = 5;
config.num_features = 25;
config.Cvalue = 0.3;
config.l2normweight = 1000;
config.verbose = 0;

% The valid options for this are 'MCR' (Margin-based Censored Regression)
%  and 'SVM'
config.method = 'MCR';

% Load the test and train data structures (random matrices with random labels)
%  For your own data, use the same structure as in this file
%  Time is assumed to be normalized from 0 to 1 where 1 means
%   the event did not occur in the course of the study (ie censored)
load('data.mat');

% Get the conservative mean estimate of features
disp('Getting conservative mean estimates...');
resultsCM = getWeightedCM(train, config);
disp('done!');

% Calculate the cross-validation and train ROC at different thresholds
%  The thresholds are used to select the number of features to use
disp('Getting ROC at different thresholds...');
[threshold_train_roc, threshold_cv_roc, thresholds] = getThresholdROC(train, resultsCM, config);
disp('done!');

% Find the best threshold using max(2*CV ROC - Train ROC)
[max_cv threshold_idx] = max(threshold_cv_roc-(threshold_train_roc-threshold_cv_roc));
best_threshold = thresholds(threshold_idx);

% Trim the data to use the appropriate number of features
train.data = train.data(:, resultsCM.cv_roc>=best_threshold);
test.data = test.data(:, resultsCM.cv_roc>=best_threshold);

% Get the final results on the test set
final_results.testResults = runAlgorithm(train, test, config);
final_results.resultsCM = resultsCM;
final_results.thresholds = thresholds;
final_results.threshold_cv_roc = threshold_cv_roc;
final_results.threshold_train_roc = threshold_train_roc;
final_results.num_features = length(find(resultsCM.cv_roc>=best_threshold));

disp(['Train AUC: ' num2str(final_results.testResults.train_auc) ...
      ', Test AUC: ' num2str(final_results.testResults.test_auc) ... 
      ', Train CI: ' num2str(final_results.testResults.train_ci)  ...
      ', Test CI: ' num2str(final_results.testResults.test_ci)]);
